pub trait Tokenizer {
// Required method
fn tokenize<'a>(
&'a self,
text: &'a str,
) -> JPreprocessResult<Vec<impl 'a + Token>>;
}Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl Tokenizer for Tokenizer
Available on crate feature vibrato only.Vibrato support is experimental and may be removed or changed in the future. Use with caution.
impl Tokenizer for Tokenizer
Available on crate feature
vibrato only.Vibrato support is experimental and may be removed or changed in the future. Use with caution.