pub struct WordDetailsLine {
pub pos: String,
pub pos_group1: String,
pub pos_group2: String,
pub pos_group3: String,
pub ctype: String,
pub cform: String,
pub orig: String,
pub read: String,
pub pron: String,
pub acc_morasize: String,
pub chain_rule: String,
pub chain_flag: String,
}Expand description
A struct to represent a line in a word dictionary file.
This struct is experimental and may change in the future.
Fields
pos: Stringpos_group1: Stringpos_group2: Stringpos_group3: Stringctype: Stringcform: Stringorig: Stringread: Stringpron: Stringacc_morasize: Stringchain_rule: Stringchain_flag: StringImplementations